@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = "1.00";
+our $VERSION = "1.01";
 
 use Cwd;
 use Term::ReadLine;
@@ -17,13 +17,15 @@ use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
 
 my $HAVE_LexPersist = 0;
-eval "use App::PerlShell::LexPersist";
+eval "use Lexical::Persistence 1.01 ()";
 if ( !$@ ) {
+    eval "use App::PerlShell::LexPersist";
     $HAVE_LexPersist = 1;
 }
 my $HAVE_ModRefresh = 0;
-eval "use App::PerlShell::ModRefresh";
+eval "use Module::Refresh";
 if ( !$@ ) {
+    eval "use App::PerlShell::ModRefresh";
     $HAVE_ModRefresh = 1;
 }
 
